## Documentation

The filler Python library provides a way to sequentially fill a list of data into a docx template, resulting in a batch of pre-filled docx files. For example, a teacher can automatically fill a list of award-winning students into a certificate template, thereby generating a certificate for each student.

